@@ -48,7 +48,6 @@ class ContentType(tuple):
     def subtype(self):
         return tuple.__getitem__(self, 0).split('/')[1]
 
-
     def is_content_type(self):
         return True
 
@@ -69,13 +68,17 @@ class ContentType(tuple):
     def is_headers_container(self):
         return self.is_feedback_report() or \
             self.is_rfc_headers() or \
+            self.is_message_external_body() or \
             self.is_disposition_notification()
 
     def is_rfc_headers(self):
         return self == 'text/rfc822-headers'
 
+    def is_message_external_body(self):
+        return self == 'message/external-body'
+
     def is_message_container(self):
-        return self == 'message/rfc822'
+        return self == 'message/rfc822' or self == 'message/news'
 
     def is_disposition_notification(self):
         return self == 'message/disposition-notification'
@@ -87,23 +90,27 @@ class ContentType(tuple):
         return self == 'message/feedback-report'
 
     def is_delivery_report(self):
-         return self == 'multipart/report'
+        return self == 'multipart/report'
 
     def get_boundary(self):
         return self.params.get("boundary")
 
     def get_boundary_line(self, final=False):
-        return "--{}{}".format(
+        return "--{0}{1}".format(
             self.get_boundary(), "--" if final else "")
 
     def get_charset(self):
-        return self.params.get("charset", 'ascii').lower()
+        default = 'ascii' if self.main == 'text' else None
+        c = self.params.get("charset", default)
+        if c:
+            c = c.lower()
+        return c
 
     def set_charset(self, value):
         self.params["charset"] = value.lower()
 
     def __str__(self):
-        return "{}/{}".format(self.main, self.sub)
+        return "{0}/{1}".format(self.main, self.sub)
 
     def __eq__(self, other):
         if isinstance(other, ContentType):
@@ -120,6 +127,10 @@ class ContentType(tuple):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def __repr__(self):
+        return "ContentType('{}', '{}', {!r})".format(self.main, self.sub,
+                                                      self.params)
+
 
 class MessageId(str):
 
@@ -131,7 +142,7 @@ class MessageId(str):
         return str.__new__(cls, *args, **kw)
 
     def __clean(self):
-        return self.replace('"','').replace("'", '')
+        return self.replace('"', '').replace("'", '')
 
     def __hash__(self):
         return hash(self.__clean())
@@ -154,7 +165,7 @@ class MessageId(str):
         message_id = make_msgid().strip("<>")
         if domain:
             local = message_id.split('@')[0]
-            message_id = "{}@{}".format(local, domain)
+            message_id = "{0}@{1}".format(local, domain)
         return cls(message_id)
 
     @classmethod
@@ -178,4 +189,3 @@ class Subject(unicode):
 
     def strip_replies(self):
         return self.RE_RE.sub('', self)
-
